Class: Scheming::Type::Base
- Inherits:
-
Object
- Object
- Scheming::Type::Base
- Defined in:
- lib/scheming/type.rb
Overview
Base Type Definition
Any and all shared functionality comes from this base type definition.
Any and all shared functionality comes from this base type definition.